mater\_data\_providing.serialization
====================================

.. automodule:: mater_data_providing.serialization

   
   .. rubric:: Functions

   .. autosummary::
   
      dump_json
      standardize_json
      to_mater_json
   